#
# spec file for package rtmidi
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   7
Name:           rtmidi
Version:        6.0.0
Release:        2.5
Summary:        C++ library for realtime MIDI input/ouput
License:        MIT
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://www.music.mcgill.ca/~gary/rtmidi/index.html
Source0:        https://www.music.mcgill.ca/~gary/rtmidi/release/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE pkgconfig.patch avvissu@yandex.ru
Patch0:         rtmidi-6.0.0-pkgconfig.patch
# PATCH-FIX-OPENSUSE set proper .cmake files path, lower cmake version for Leap (3.24 is required for Android)
Patch1:         rtmidi-cmake.patch
# PATCH-FIX-UPSTREAM ALSA: Avoid listing ports that are usually from 3rd.party
Patch2:         ALSA-Avoid-listing-ports-that-are-usually-from-3rd-party.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)

%description
RtMidi is a set of C++ classes (RtMidiIn, RtMidiOut and API-specific
classes) that provides a common API (Application Programming Interface) for
realtime MIDI input/output across ALSA & JACK.

%package -n     lib%{name}%{sover}
Summary:        C++ library for realtime MIDI input/ouput
Group:          System/Libraries

%description -n lib%{name}%{sover}
RtMidi is a set of C++ classes (RtMidiIn, RtMidiOut and API-specific
classes) that provides a common API (Application Programming Interface) for
realtime MIDI input/output across ALSA & JACK.

This package provides the shared library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}
Requires:       pkgconfig(alsa)
Requires:       pkgconfig(jack)

%description    devel
C++ library for realtime MIDI input/ouput.

This package contains header files and libraries needed to develop
application that use %{name}.

%prep
%setup -q
%autopatch -p1

%build

# generate rtmidi-config for compatibility
%configure --disable-static \
    --with-jack \
    --with-alsa

%cmake
%cmake_build

%install
%cmake_install
install -Dm0755 %{name}-config %{buildroot}%{_bindir}/%{name}-config
find %{buildroot} -type f -name "*.la" -delete -print

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}.so.*

%files devel
%license README.md
%{_bindir}/%{name}-config
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}

%changelog
* Sun Nov 26 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- fix rtmidi.pc:
  rework rtmidi-4.0.0-pkgconfig.patch to rtmidi-6.0.0-pkgconfig.patch
  update rtmidi-cmake.patch
- add ALSA-Avoid-listing-ports-that-are-usually-from-3rd-party.patch
  from upstream
* Sun Nov 19 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Switch build to cmake
- add rtmidi-cmake.patch
- Update to version 6.0.0
  * run "git log 5.0.0..HEAD" to see commits since last release
  * new Android API (thanks to YellowLabrador!)
  * new Windows UWP API support (thanks to Masamichi Hosoda!)
  * various build system updates and code efficiencies
* Sat Dec 18 2021 Simon Lees <sflees@suse.de>
- Update to Version 5.0.0
  * see git history for complete list of changes
  * new Web MIDI API
  * iOS support
  * new setBufferSize() function
  * fixes for WinMM, Jack
  * added C API test program
  * now requiring C++11
  * build system updates
  * midiprobe probes all compiled APIs
  * various build system updates and code efficiencies
- Refreshed rtmidi-4.0.0-pkgconfig.patch
* Mon Apr 22 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 4.0.0
  * see git history for complete list of changes
  * updates to test programs to clarify port numbering
  * new C API wrapper
  * new functions to get API names
  * miscellaneous sysex fixes in Jack and ALSA
  * new setPortName() method (for Jack and ALSA)
  * new setClientName() method (for ALSA)
  * various build system updates and code efficiencies
- Refreshed rtmidi-2.1.1-pkgconfig.patch as
  rtmidi-4.0.0-pkgconfig.patch
* Thu Apr 19 2018 aloisio@gmx.com
- Update to version 3.0.0
  * The version number has been bumped to 3.0.0 because of the
    past API change concerning the renaming of the RtError class
    to RtMidiError. Changes in this release include:
    + see git history for complete list of changes
    + new sendMessage() function that does not use std::vector
    + various std::string updates, including use of UTF8 for port
    names
    + fixes for the MIDI queue
    + various build system updates and code efficiencies
- Spec cleanup
* Thu May 25 2017 avvissu@yandex.by
- Change path to headers
- Drop _service file
* Mon Jan 30 2017 edogawa@aon.at
- Update to version 2.1.1
  * update pkgconfig.patch
* Wed Jun 24 2015 avvissu@yandex.ru
- Initial release
